/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface BotManagementConfig extends cdktf.TerraformMetaArguments {
    /**
    * Automatically update to the newest bot detection models created by Cloudflare as they are released. [Learn more.](https://developers.cloudflare.com/bots/reference/machine-learning-models#model-versions-and-release-notes).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#auto_update_model BotManagement#auto_update_model}
    */
    readonly autoUpdateModel?: boolean | cdktf.IResolvable;
    /**
    * Use lightweight, invisible JavaScript detections to improve Bot Management. [Learn more about JavaScript Detections](https://developers.cloudflare.com/bots/reference/javascript-detections/).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#enable_js BotManagement#enable_js}
    */
    readonly enableJs?: boolean | cdktf.IResolvable;
    /**
    * Whether to enable Bot Fight Mode.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#fight_mode BotManagement#fight_mode}
    */
    readonly fightMode?: boolean | cdktf.IResolvable;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#id BotManagement#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether to optimize Super Bot Fight Mode protections for Wordpress.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#optimize_wordpress BotManagement#optimize_wordpress}
    */
    readonly optimizeWordpress?: boolean | cdktf.IResolvable;
    /**
    * Super Bot Fight Mode (SBFM) action to take on definitely automated requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#sbfm_definitely_automated BotManagement#sbfm_definitely_automated}
    */
    readonly sbfmDefinitelyAutomated?: string;
    /**
    * Super Bot Fight Mode (SBFM) action to take on likely automated requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#sbfm_likely_automated BotManagement#sbfm_likely_automated}
    */
    readonly sbfmLikelyAutomated?: string;
    /**
    * Super Bot Fight Mode (SBFM) to enable static resource protection. Enable if static resources on your application need bot protection. Note: Static resource protection can also result in legitimate traffic being blocked.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#sbfm_static_resource_protection BotManagement#sbfm_static_resource_protection}
    */
    readonly sbfmStaticResourceProtection?: boolean | cdktf.IResolvable;
    /**
    * Super Bot Fight Mode (SBFM) action to take on verified bots requests.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#sbfm_verified_bots BotManagement#sbfm_verified_bots}
    */
    readonly sbfmVerifiedBots?: string;
    /**
    * Whether to disable tracking the highest bot score for a session in the Bot Management cookie.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#suppress_session_score BotManagement#suppress_session_score}
    */
    readonly suppressSessionScore?: boolean | cdktf.IResolvable;
    /**
    * The zone identifier to target for the resource. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#zone_id BotManagement#zone_id}
    */
    readonly zoneId: string;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management cloudflare_bot_management}
*/
export declare class BotManagement extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_bot_management";
    /**
    * Generates CDKTF code for importing a BotManagement resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the BotManagement to import
    * @param importFromId The id of the existing BotManagement that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the BotManagement to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/bot_management cloudflare_bot_management} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options BotManagementConfig
    */
    constructor(scope: Construct, id: string, config: BotManagementConfig);
    private _autoUpdateModel?;
    get autoUpdateModel(): boolean | cdktf.IResolvable;
    set autoUpdateModel(value: boolean | cdktf.IResolvable);
    resetAutoUpdateModel(): void;
    get autoUpdateModelInput(): boolean | cdktf.IResolvable | undefined;
    private _enableJs?;
    get enableJs(): boolean | cdktf.IResolvable;
    set enableJs(value: boolean | cdktf.IResolvable);
    resetEnableJs(): void;
    get enableJsInput(): boolean | cdktf.IResolvable | undefined;
    private _fightMode?;
    get fightMode(): boolean | cdktf.IResolvable;
    set fightMode(value: boolean | cdktf.IResolvable);
    resetFightMode(): void;
    get fightModeInput(): boolean | cdktf.IResolvable | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _optimizeWordpress?;
    get optimizeWordpress(): boolean | cdktf.IResolvable;
    set optimizeWordpress(value: boolean | cdktf.IResolvable);
    resetOptimizeWordpress(): void;
    get optimizeWordpressInput(): boolean | cdktf.IResolvable | undefined;
    private _sbfmDefinitelyAutomated?;
    get sbfmDefinitelyAutomated(): string;
    set sbfmDefinitelyAutomated(value: string);
    resetSbfmDefinitelyAutomated(): void;
    get sbfmDefinitelyAutomatedInput(): string | undefined;
    private _sbfmLikelyAutomated?;
    get sbfmLikelyAutomated(): string;
    set sbfmLikelyAutomated(value: string);
    resetSbfmLikelyAutomated(): void;
    get sbfmLikelyAutomatedInput(): string | undefined;
    private _sbfmStaticResourceProtection?;
    get sbfmStaticResourceProtection(): boolean | cdktf.IResolvable;
    set sbfmStaticResourceProtection(value: boolean | cdktf.IResolvable);
    resetSbfmStaticResourceProtection(): void;
    get sbfmStaticResourceProtectionInput(): boolean | cdktf.IResolvable | undefined;
    private _sbfmVerifiedBots?;
    get sbfmVerifiedBots(): string;
    set sbfmVerifiedBots(value: string);
    resetSbfmVerifiedBots(): void;
    get sbfmVerifiedBotsInput(): string | undefined;
    private _suppressSessionScore?;
    get suppressSessionScore(): boolean | cdktf.IResolvable;
    set suppressSessionScore(value: boolean | cdktf.IResolvable);
    resetSuppressSessionScore(): void;
    get suppressSessionScoreInput(): boolean | cdktf.IResolvable | undefined;
    get usingLatestModel(): cdktf.IResolvable;
    private _zoneId?;
    get zoneId(): string;
    set zoneId(value: string);
    get zoneIdInput(): string | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
