/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface WebAnalyticsRuleConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#account_id WebAnalyticsRule#account_id}
    */
    readonly accountId: string;
    /**
    * The host to apply the rule to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#host WebAnalyticsRule#host}
    */
    readonly host: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#id WebAnalyticsRule#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Whether the rule includes or excludes the matched traffic from being measured in Web Analytics.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#inclusive WebAnalyticsRule#inclusive}
    */
    readonly inclusive: boolean | cdktf.IResolvable;
    /**
    * Whether the rule is paused or not.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#is_paused WebAnalyticsRule#is_paused}
    */
    readonly isPaused: boolean | cdktf.IResolvable;
    /**
    * A list of paths to apply the rule to.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#paths WebAnalyticsRule#paths}
    */
    readonly paths: string[];
    /**
    * The Web Analytics ruleset id. **Modifying this attribute will force creation of a new resource.**
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#ruleset_id WebAnalyticsRule#ruleset_id}
    */
    readonly rulesetId: string;
    /**
    * timeouts block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#timeouts WebAnalyticsRule#timeouts}
    */
    readonly timeouts?: WebAnalyticsRuleTimeouts;
}
export interface WebAnalyticsRuleTimeouts {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#create WebAnalyticsRule#create}
    */
    readonly create?: string;
}
export declare function webAnalyticsRuleTimeoutsToTerraform(struct?: WebAnalyticsRuleTimeouts | cdktf.IResolvable): any;
export declare class WebAnalyticsRuleTimeoutsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): WebAnalyticsRuleTimeouts | cdktf.IResolvable | undefined;
    set internalValue(value: WebAnalyticsRuleTimeouts | cdktf.IResolvable | undefined);
    private _create?;
    get create(): string;
    set create(value: string);
    resetCreate(): void;
    get createInput(): string | undefined;
}
/**
* Represents a {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule cloudflare_web_analytics_rule}
*/
export declare class WebAnalyticsRule extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_web_analytics_rule";
    /**
    * Generates CDKTF code for importing a WebAnalyticsRule resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the WebAnalyticsRule to import
    * @param importFromId The id of the existing WebAnalyticsRule that should be imported. Refer to the {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the WebAnalyticsRule to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/cloudflare/cloudflare/4.19.0/docs/resources/web_analytics_rule cloudflare_web_analytics_rule} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options WebAnalyticsRuleConfig
    */
    constructor(scope: Construct, id: string, config: WebAnalyticsRuleConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    private _host?;
    get host(): string;
    set host(value: string);
    get hostInput(): string | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _inclusive?;
    get inclusive(): boolean | cdktf.IResolvable;
    set inclusive(value: boolean | cdktf.IResolvable);
    get inclusiveInput(): boolean | cdktf.IResolvable | undefined;
    private _isPaused?;
    get isPaused(): boolean | cdktf.IResolvable;
    set isPaused(value: boolean | cdktf.IResolvable);
    get isPausedInput(): boolean | cdktf.IResolvable | undefined;
    private _paths?;
    get paths(): string[];
    set paths(value: string[]);
    get pathsInput(): string[] | undefined;
    private _rulesetId?;
    get rulesetId(): string;
    set rulesetId(value: string);
    get rulesetIdInput(): string | undefined;
    private _timeouts;
    get timeouts(): WebAnalyticsRuleTimeoutsOutputReference;
    putTimeouts(value: WebAnalyticsRuleTimeouts): void;
    resetTimeouts(): void;
    get timeoutsInput(): cdktf.IResolvable | WebAnalyticsRuleTimeouts | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
